@@ -1,6 +1,6 @@
 #__init__.py
 # Version of pepfeature package
-__version__ = "1.0.3"
+__version__ = "1.0.4"
 
 """Import all modules that exist in the current directory."""
 # Ref https://stackoverflow.com/a/60861023/
@@ -18,7 +18,7 @@ __all__ = ["aa_all_feat", "aa_composition", "aa_CT", "aa_descriptors","aa_kmer_c
            , "aa_num_of_atoms", "aa_proportion", "aa_seq_entropy", "_test"]
 
 # Let users know if they're missing any of our hard dependencies
-hard_dependencies = ("pandas", "numpy", "setuptools")
+hard_dependencies = ("pandas", "numpy", "setuptools", "xlrd")
 missing_dependencies = []
 
 for dependency in hard_dependencies:
